@@ -15,24 +15,6 @@ from util import (
   imgs_from_html, utc_now, logger
   )
 
-try:
-  import gevent
-  from gevent.pool import Pool
-
-  # patch everything except for thread.
-  import gevent.monkey
-  gevent.monkey.patch_socket()
-  gevent.monkey.patch_ssl()
-  gevent.monkey.patch_os()
-  gevent.monkey.patch_time()
-  gevent.monkey.patch_select()
-  gevent.monkey.patch_subprocess()
-
-except ImportError:
-  imported_gevent = False
-else:
-  imported_gevent = True
-
 # JSONPATH CANDIDATES
 URL_CANDIDATE_JSONPATH = [
   'id', 'feedburner_origlink', 'link', 'link[*].href'
@@ -216,49 +198,49 @@ class SupeRSS:
 
     return data
 
-  def merge_extracted_data(self, feed_data, extracted_data):
-    d = feed_data.copy()
+  # def merge_extracted_data(self, feed_data, extracted_data):
+  #   d = feed_data.copy()
 
-    try:
-      # TODO: better merge heuristics
-      d['article_html'] = extracted_data['article_html']
-      d['text'] = extracted_data['text']
+  #   try:
+  #     # TODO: better merge heuristics
+  #     d['article_html'] = extracted_data['article_html']
+  #     d['text'] = extracted_data['text']
 
-      # add lists together
-      d['tags'] = list(set(feed_data['tags'] + extracted_data['tags']))
-      d['authors'] = list(set(feed_data['authors'] + extracted_data['authors']))
-      d['img_urls'] = list(set(feed_data['img_urls'] + extracted_data['img_urls']))
-      d['article_links'] = list(set(feed_data['article_links'] + extracted_data['article_links']))
-      d['article_imgs'] = list(set(feed_data['article_imgs'] + extracted_data['article_imgs']))
+  #     # add lists together
+  #     d['tags'] = list(set(feed_data['tags'] + extracted_data['tags']))
+  #     d['authors'] = list(set(feed_data['authors'] + extracted_data['authors']))
+  #     d['img_urls'] = list(set(feed_data['img_urls'] + extracted_data['img_urls']))
+  #     d['article_links'] = list(set(feed_data['article_links'] + extracted_data['article_links']))
+  #     d['article_imgs'] = list(set(feed_data['article_imgs'] + extracted_data['article_imgs']))
     
-    except TypeError:
-      pass
+  #   except TypeError:
+  #     pass
     
-    return d 
+  #   return d 
   
-  def extract_and_merge(self, entry):
-    """
-    runner for non-full-text
-    """
-    p = Particle()
-    extracted_data = p.extract(url=entry['url'])
-    return self.merge_extracted_data(entry, extracted_data)
+  # def extract_and_merge(self, entry):
+  #   """
+  #   runner for non-full-text
+  #   """
+  #   p = Particle()
+  #   extracted_data = p.extract(url=entry['url'])
+  #   return self.merge_extracted_data(entry, extracted_data)
 
   def run_concurrent(self, func, iterator):
 
-    if self.concurrent:
-      pool = Pool(self.num_workers)
-      for result in pool.imap_unordered(func, iterator):
-        yield result 
+    # if self.concurrent:
+    #   pool = Pool(self.num_workers)
+    #   for result in pool.imap_unordered(func, iterator):
+    #     yield result 
 
-    elif not self.concurrent:
-      logger.warn('SupeRSS requires gevent run concurrently.')
-      for item in iterator:
-        yield func(item)
+    # elif not self.concurrent:
+    #   logger.warn('SupeRSS requires gevent run concurrently.')
+    #   for item in iterator:
+    #     yield func(item)
 
-    else:
-      for item in iterator:
-        yield func(item)
+    # else:
+    for item in iterator:
+      yield func(item)
 
   def run_full_text(self):
     """
